@@ -22,10 +22,11 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package SQL::Functional;
-$SQL::Functional::VERSION = '0.2';
+$SQL::Functional::VERSION = '0.3';
 use strict;
 use warnings;
 use SQL::Functional::AndClause;
+use SQL::Functional::CountClause;
 use SQL::Functional::DeleteClause;
 use SQL::Functional::DistinctClause;
 use SQL::Functional::FromClause;
@@ -92,6 +93,7 @@ our @EXPORT_OK = qw{
     DISTINCT
     func
     literal
+    COUNT
 };
 our @EXPORT = @EXPORT_OK;
 
@@ -106,17 +108,17 @@ sub SELECT ($$@)
 
     if( ref $fields eq 'ARRAY' ) {
         @fields = map {
-            (ref($_) && $_->isa( 'SQL::Functional::FieldClause' ))
+            (ref($_) && $_->does( 'SQL::Functional::FieldRole' ))
                 ? $_
                 : SQL::Functional::FieldClause->new({
                     name => $_,
                 });
         } @$fields;
     }
-    elsif( $fields->isa( 'SQL::Functional::FieldClause' ) ) {
+    elsif( ref $fields && $fields->does( 'SQL::Functional::FieldRole' ) ) {
         @fields = ($fields);
     }
-    elsif( $fields->isa( 'SQL::Functional::DistinctClause' ) ) {
+    elsif( ref $fields && $fields->isa( 'SQL::Functional::DistinctClause' ) ) {
         @fields = ($fields->fields);
         $is_distinct = 1;
     }
@@ -205,7 +207,7 @@ sub match($$$)
         ref($value) && $value->does( 'SQL::Functional::Clause' )
         ? $value
         : SQL::Functional::PlaceholderClause->new({
-            value => $value,
+            literal => $value,
         });
     my $clause = SQL::Functional::MatchClause->new({
         field => $field_obj,
@@ -374,7 +376,7 @@ sub VALUES ($)
 {
     my ($values) = @_;
     my $clause = SQL::Functional::ValuesClause->new(
-        params => $values,
+        clauses => $values,
     );
     return $clause;
 }
@@ -532,6 +534,35 @@ sub literal ($)
     return $clause;
 }
 
+sub COUNT ($)
+{
+    my ($fields) = @_;
+    my @fields;
+
+    if( ref $fields eq 'ARRAY' ) {
+        @fields = map {
+            (ref($_) && $_->isa( 'SQL::Functional::FieldClause' ))
+                ? $_
+                : SQL::Functional::FieldClause->new({
+                    name => $_,
+                });
+        } @$fields;
+    }
+    elsif( $fields->isa( 'SQL::Functional::FieldClause' ) ) {
+        @fields = ($fields);
+    }
+    else {
+        @fields = ( SQL::Functional::FieldClause->new({
+            name => $fields,
+        }) );
+    }
+    
+    my $clause = SQL::Functional::CountClause->new({
+        fields => \@fields,
+    });
+    return $clause;
+}
+
 
 1;
 __END__
@@ -878,11 +909,24 @@ function name, followed by any parameters.
 
 =head3 literal
 
-Not yet implemented.
+Creates a L<SQL::Functional::LiteralClause> and returns it. 
+Takes a string which will be put literally into the final SQL, rather than as 
+a placeholder.
 
-When it is, it will create a L<SQL::Functional::LiteralClause> and returns it. 
-Takes a string which will be put literally into the final SQL, rather than as a 
-placeholder.
+=head3 COUNT
+
+Creates a L<SQL::Functional::CountClause> and returns it. Takes a set of 
+fields, which could be passed as:
+
+=over 4
+
+=item * Scalar String -- for a single field
+
+=item * ArrayRef of Strings -- for several fields
+
+=item * An object that does L<SQL::Functional::FieldRole>.
+
+=back
 
 =head1 WRITING EXTENSIONS
 
@@ -895,9 +939,9 @@ module to get started.
 I should preface this section by saying that I'm not trying to insult the 
 developers of C<SQL::Abstract> or C<DBIx::Class>. They've obviously worked 
 hard to create successful and widely used libraries for a very common task. 
-Perl is better for what they've accomplished.  That said, I think they're stuck 
-in an object-oriented way of thinking in a problem space that could be expressed
-more naturally with functions.
+Perl is better for what they've accomplished.  That said, I think they're 
+stuck in an object-oriented way of thinking in a problem space that could be 
+expressed more naturally with functions.
 
 Existing ways of making database calls fall into one of three approaches: 
 direct string manipulation by hand, an object interface that outputs SQL 
