@@ -22,24 +22,63 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package SQL::Functional::Clause;
-$SQL::Functional::Clause::VERSION = '0.2';
+$SQL::Functional::Clause::VERSION = '0.3';
 use strict;
 use warnings;
 use Moose::Role;
+use Moose::Util::TypeConstraints;
+
+
+subtype 'SQL::Functional::Type::Literals',
+    as 'ArrayRef[SQL::Functional::LiteralClause]';
+coerce 'SQL::Functional::Type::Literals',
+    from 'ArrayRef[Str|SQL::Functional::LiteralClause]',
+    via {
+        my @args = @$_;
+        my @new_args = map {
+            ref $_
+                ? $_
+                : SQL::Functional::PlaceholderClause->new({
+                    literal => $_,
+                });
+        } @args;
+        return \@new_args;
+    };
+
+subtype 'SQL::Functional::Type::Clauses',
+    as 'ArrayRef[SQL::Functional::Clause]';
+coerce 'SQL::Functional::Type::Clauses',
+    from 'ArrayRef[Str|SQL::Functional::Clause]',
+    via {
+        my @args = @$_;
+        my @new_args = map {
+            ref $_
+                ? $_
+                : SQL::Functional::PlaceholderClause->new({
+                    literal => $_,
+                });
+        } @args;
+        return \@new_args;
+    };
+
 
 has params => (
     is => 'ro',
-    isa => 'ArrayRef[Str]',
+    isa => 'SQL::Functional::Type::Clauses',
     default => sub {[]},
     auto_deref => 1,
 );
 
 requires 'to_string';
 
+
 sub get_params
 {
     my ($self) = @_;
-    return $self->params;
+    my @params = map {
+        $_->get_params
+    } $self->params;
+    return @params;
 }
 
 
@@ -55,12 +94,24 @@ __END__
 
 A Moose role for representing SQL strings.
 
+=head1 PROVIDED MOOSE TYPES
+
+=head2 SQL::Functional::Type::Literals
+
+An array ref of C<SQL::Functional::LiteralClause> objects.  It will 
+automatically coerce any strings in the array to C<PlacheolderClause>s.
+
+=head2 SQL::Functional::Type::Clauses
+
+An array ref of C<SQL::Functional::Clause> objects. It will automatically 
+coerce any strings in the array to C<PlaceholderClause>s.
+
 =head1 PROVIDED ATTRIBUTES
 
 =head2 params
 
-Arrayref of strings. These represent the bind parameters of your clause. 
-Has C<auto_deref> set, so you can say:
+Type C<SQL::Functional::Type::Clauses>. These represent the parameters of 
+your clause.  Has C<auto_deref> set, so you can say:
 
   my @params = $obj->params;
 
@@ -71,9 +122,8 @@ of subclauses recursively.
 
 =head1 get_params
 
-By default, this returns the same thing as C<params>. However, since many 
-clauses will need to contain other clauses, overriding this allows for a 
-simple mechanism for recursively picking up the params of subclauses.
+As of version 0.3, this will recurse into calling C<params> on subclauses by 
+default. It can be overriden to get only C<params> if need be.
 
 =head1 REQUIRED METHODS
 
