@@ -22,14 +22,16 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package SQL::Functional::FieldClause;
-$SQL::Functional::FieldClause::VERSION = '0.2';
+$SQL::Functional::FieldClause::VERSION = '0.3';
 use strict;
 use warnings;
 use Moose;
 use namespace::autoclean;
 use SQL::Functional::Clause;
+use SQL::Functional::FieldRole;
 
 with 'SQL::Functional::Clause';
+with 'SQL::Functional::FieldRole';
 
 has name => (
     is => 'ro',
