@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package SQL::Functional::GroupByClause;
-$SQL::Functional::GroupByClause::VERSION = '0.2';
+$SQL::Functional::GroupByClause::VERSION = '0.3';
 use strict;
 use warnings;
 use Moose;
@@ -33,7 +33,7 @@ with 'SQL::Functional::Clause';
 
 has 'field' => (
     is => 'ro',
-    isa => 'SQL::Functional::FieldClause',
+    isa => 'SQL::Functional::FieldRole',
     required => 1,
 );
 
