@@ -22,28 +22,22 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package SQL::Functional::PlaceholderClause;
-$SQL::Functional::PlaceholderClause::VERSION = '0.2';
+$SQL::Functional::PlaceholderClause::VERSION = '0.3';
 use strict;
 use warnings;
 use Moose;
 use namespace::autoclean;
 use SQL::Functional::Clause;
 
-with 'SQL::Functional::Clause';
+extends 'SQL::Functional::LiteralClause';
 
 
-has value => (
-    is => 'ro',
-    isa => 'Str',
-    required => 1,
-);
-
 sub to_string { '?' }
 
 sub get_params
 {
     my ($self) = @_;
-    return $self->value;
+    return ($self->literal);
 }
 
 
