@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package SQL::Functional::SelectClause;
-$SQL::Functional::SelectClause::VERSION = '0.2';
+$SQL::Functional::SelectClause::VERSION = '0.3';
 use strict;
 use warnings;
 use Moose;
@@ -35,7 +35,7 @@ with 'SQL::Functional::Clause';
 
 has fields => (
     is => 'ro',
-    isa => 'ArrayRef[SQL::Functional::FieldClause]',
+    isa => 'ArrayRef[SQL::Functional::FieldRole]',
     required => 1,
     auto_deref => 1,
 );
