@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package SQL::Functional::ValuesClause;
-$SQL::Functional::ValuesClause::VERSION = '0.2';
+$SQL::Functional::ValuesClause::VERSION = '0.3';
 use strict;
 use warnings;
 use Moose;
@@ -31,12 +31,28 @@ use SQL::Functional::Clause;
 
 with 'SQL::Functional::Clause';
 
+has 'clauses' => (
+    is => 'ro',
+    isa => 'SQL::Functional::Type::Clauses',
+    coerce => 1,
+);
 
 sub to_string
 {
     my ($self) = @_;
-    my @params = $self->params;
-    return 'VALUES (' . join( ', ', ('?') x scalar(@params) ) . ')';
+    my @params = @{ $self->clauses };
+    return 'VALUES (' . join( ', ', map {
+        $_->to_string
+    } @params ) . ')';
+}
+
+sub get_params
+{
+    my ($self) = @_;
+    my @params = map {
+        $_->get_params;
+    } @{ $self->clauses };
+    return @params;
 }
 
 
